<?php
 /*
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License version 3.0
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zinrelo.com so we can send you a copy immediately.
 *
 * @category  Zinrelo
 * @package   Zinrelo_Extension
 * @copyright Copyright (c) 2017 Zinrelo, Inc.
 * @license   https://opensource.org/licenses/osl-3.0.php Open Software License version 3.0
 */

/**
 * Extension add OrderSnippet block in footer.
 *
 * @category Zinrelo
 * @package  Zinrelo_Extension
 * @author   Zinrelo Developer <dev@zinrelo.com>
 */
	 
	namespace Zinrelo\Extension\Block;
	use Magento\Catalog\Model\Category;
	use Magento\Catalog\Model\Product;
	
	class OrderSnippet extends \Magento\Framework\View\Element\Template
	{
		/**
        * @var \Magento\Framework\App\Config\ScopeConfigInterface
        */
		
		protected $_scopeConfig;
		
		/**
        * @var \Magento\Catalog\Model\Product
        */
		
		protected $_product;
		
		/**
        * @var \Magento\Catalog\Model\Category
        */
		
		protected $_category;
		
		/**
        * @var \Magento\Store\Model\StoreManagerInterface
        */
		protected $_storeManagerInterface;
		
		/**
        * @var \Magento\Sales\Model\Order
        */
		
		protected $_salesFactory;
		/**
        * @var \Magento\Checkout\Model\Session
        */
		
		protected $_checkoutSession;
		
		/**
		 * @param Context $context
		 * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
		 * @param \Magento\Catalog\Model\Product $product
		 * @param \Magento\Catalog\Model\Category $category
		 * @param \Magento\Store\Model\StoreManagerInterface $storeManagerInterface
		 * @param \Magento\Sales\Model\Order $salesOrderFactory
		 * @param \Magento\Checkout\Model\Session $checkoutSession
		 * @param array $data
		 */
		public function __construct(
			\Magento\Framework\View\Element\Template\Context $context,
			\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
			\Magento\Catalog\Model\Product $product,
			\Magento\Catalog\Model\Category $category,
			\Magento\Store\Model\StoreManagerInterface $storeManagerInterface,
			\Magento\Sales\Model\Order $salesOrderFactory,
			\Magento\Checkout\Model\Session $checkoutSession,
			array $data = []
		) {
			$this->_scopeConfig = $scopeConfig;
			$this->_checkoutSession = $checkoutSession;
			$this->_product=$product;
			$this->_category=$category;
			$this->_storeManagerInterface=$storeManagerInterface;
			$this->_salesFactory=$salesOrderFactory;
			
			parent::__construct($context, $data);
		  }
		  
		/* Check Configuration Extenstion Enable  
		*  @return Boolean
		*/
		public  function _isEnabled()
		{
			return $this->_scopeConfig->getValue('zinrelo_settings/settings/extension_active',
			\Magento\Store\Model\ScopeInterface::SCOPE_STORE
			);
		
		}
		
		/**
		* Retrieve current order details
		* 
		* @return Array 
		*/
		
		public function getOrder()
		{
		
			$orderId = $this->_getLastOrderId();
			// Call @param \Magento\Sales\Model\Order 
			$order   = $this->_salesFactory->load($orderId);
			//Store Values into array
			$orderData = [];
			$orderData['orderdata']['order_id'] = $order->getIncrementId();
			$orderData['orderdata']['discount_code'] = $order->getCouponCode();
			$orderData['orderdata']['total'] = $order->getGrandTotal();
			$orderData['orderdata']['subtotal'] =  $order->getSubtotal();
			$orderData['orderdata']['currency_code'] = $order->getBaseCurrency()->getCurrencyCode();
			$items = $order->getAllVisibleItems();
			$i=0;
			$productData =[];
			foreach ($items as $itemId => $item) {
				$product = $this->_product->load($item->getProductId());
				$categories = $product->getCategoryIds();
				$productData[$i]['product_id'] = $product->getId();
				$productData[$i]['quantity'] = $item->getQtyOrdered();
				$productData[$i]['price'] = $item->getPrice();
				$productData[$i]['img_url'] = $this->getImageUrl($product);
				$productData[$i]['title'] = $product->getName();
				$productData[$i]['url'] = $product->getProductUrl();
				$productData[$i]['category'] =$this->_category->load($categories[0])->getName();
				$i++;
			}
			$orderData['products'] = $productData;
			return $orderData;
					
		}
		
		/* Retrieve last Order Id
		* @return INT
 	    */
		public function _getLastOrderId()
		{
		
			return $this->_checkoutSession->getLastOrderId();
		
		}
		
		/*Retrieve Images Url of Product
		* @Return String Or NULL;
		*/
		public function  getImageUrl($product)
		{
		     
			$store = $this->_storeManagerInterface->getStore();
			
			if($product->getImage()):	
				$imageUrl = $store->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA) 
				. 'catalog/product' . $product->getImage();	
				return $imageUrl;	
			endif;
			
		   return NULL;
		
		}
	
	
	
	}