<?php
 /*
 * Magento
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Open Software License version 3.0
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/osl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@zinrelo.com so we can send you a copy immediately.
 *
 * @category  Zinrelo
 * @package   Zinrelo_Extension
 * @copyright Copyright (c) 2017 Zinrelo, Inc.
 * @license   https://opensource.org/licenses/osl-3.0.php Open Software License version 3.0
 */

/**
* Extension Button for Register .
*
* @category Zinrelo
* @package  Zinrelo_Extension
* @author   Zinrelo Developer <dev@zinrelo.com>
*/
namespace Zinrelo\Extension\Block\System\Config;

class Button extends \Magento\Config\Block\System\Config\Form\Field
{
		/**
		* @var string
		*/
		protected $_template = 'Zinrelo_Extension::system/config/button.phtml';
		/**
		* @var \Magento\Framework\App\Config\ScopeConfigInterface
		*/
		protected $_scopeConfig;
		/**
		* @var \Magento\Store\Model\StoreManagerInterface
		*/
		protected $_storeManager;
		/**
		* @var \Magento\Framework\App\RequestInterface
		*/
		protected $_request;
		/**
		* @param \Magento\Backend\Block\Template\Context $context
		* @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
		* @param \Magento\Store\Model\StoreManagerInterface $storeManager,
		* @param \Magento\Framework\App\RequestInterface $request,
		* @param array $data
		*/
		public function __construct(
			\Magento\Backend\Block\Template\Context $context,
			\Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
			\Magento\Store\Model\StoreManagerInterface $storeManager,
			\Magento\Framework\App\RequestInterface $request,
			array $data = []
		) {
			$this->_scopeConfig = $scopeConfig;
			$this->_storeManager=$storeManager;
			$this->_request=$request;
			parent::__construct($context, $data);
		}
		
		/**
		* Remove scope label
		*
		* @param  \Magento\Framework\Data\Form\Element\AbstractElement $element
		* @return string
		*/
		public function render(\Magento\Framework\Data\Form\Element\AbstractElement $element)
		{
			$element->unsScope()->unsCanUseWebsiteValue()->unsCanUseDefaultValue();
			return parent::render($element);
		}
		
		/**
		* Return element html
		*
		* @param  \Magento\Framework\Data\Form\Element\AbstractElement $element
		* @return string
		*
		* @SuppressWarnings(PHPMD.UnusedFormalParameter)
		*/
		protected function _getElementHtml(\Magento\Framework\Data\Form\Element\AbstractElement $element)
		{
			return $this->_toHtml();
		}
		
		/**
		* Return ajax url for synchronize button
		*
		* @return string
		*/
		public function getAjaxSyncUrl()
		{
			return $this->getUrl('https://app.zinrelo.com/store/magento/');
		}
		
		/**
		* Generate synchronize button html
		*
		* @return string
		*/
		public function getButtonHtml()
		{
			$button = $this->getLayout()->createBlock(
			'Magento\Backend\Block\Widget\Button'
			)->setData(
			[
			'id' => 'register_button',
			'label' => __('Register'),
			]
			);
			
			return $button->toHtml();
		}
		
		/* Retrieve partner id from configuration data
		*  @return String
		*/
		public function getPartnerId()
		{
			return $this->_scopeConfig->getValue(
			'zinrelo_settings/settings/partner_id',
			\Magento\Store\Model\ScopeInterface::SCOPE_STORE
			); 
			
		}
		
		/* Retrieve store base url
		*  @return String
		*/
		public function getStoreUrl()
		{
			return $this->_storeManager->getStore()->getBaseUrl();
		}
		
		/* Retrieve store name 
		*  @return String
		*/
		public function getStoreName()
		{
			return $this->_storeManager->getStore()->getCode();
		
		}
		/* Retrieve Store Id
		*  @return Int
		*/
		public function getStoreId()
		{
			return $this->_storeManager->getStore()->getId();
		
		}
		/* Retrieve store param
		*  @return String
		*/
		
		public function getblockParam()
		{
			return $this->_request->getParam('store',0);
		
		}
		/* Retrieve current currency code
		*  @return String
		*/
		public function getCurrentCurrencyCode()
		{
			return $this->_storeManager->getStore()->getCurrentCurrencyCode();
		}
	
	
	}